@@ -1,5 +1,5 @@
 "updateDescription" <-
 function(fn, description) {
     .Call("C_updateTTag", fn, description, PACKAGE="rtiff")
-    invisible(NULL)
+    return()
 }
